Re: [Mesa-dev] [PATCH 2/2] s/Tungsten Graphics/VMware/

2014-01-17 Thread Ian Romanick
On 01/17/2014 08:33 AM, jfons...@vmware.com wrote:
 diff --git a/src/mesa/drivers/dri/r200/r200_context.c 
 b/src/mesa/drivers/dri/r200/r200_context.c
 index f82424b..f613e56 100644
 --- a/src/mesa/drivers/dri/r200/r200_context.c
 +++ b/src/mesa/drivers/dri/r200/r200_context.c
 @@ -29,7 +29,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
 SOFTWARE.
  
  /*
   * Authors:
 - *   Keith Whitwell ke...@tungstengraphics.com
 + *   Keith Whitwell kei...@vmware.com
   */
  
  #include stdbool.h
 @@ -80,7 +80,7 @@ static const GLubyte *r200GetString( struct gl_context 
 *ctx, GLenum name )
  
 switch ( name ) {
 case GL_VENDOR:
 -  return (GLubyte *)Tungsten Graphics, Inc.;
 +  return (GLubyte *)VMware, Inc.;
  

Since VMware isn't maintaining radeon or r200, I seems like this should
be Mesa Project, like swrast.

 case GL_RENDERER:
offset = driGetRendererString( buffer, R200, agp_mode );
 diff --git a/src/mesa/drivers/dri/radeon/radeon_common_context.c 
 b/src/mesa/drivers/dri/radeon/radeon_common_context.c
 index 6dec137..487cb83 100644
 --- a/src/mesa/drivers/dri/radeon/radeon_common_context.c
 +++ b/src/mesa/drivers/dri/radeon/radeon_common_context.c
 @@ -80,7 +80,7 @@ static const GLubyte *radeonGetString(struct gl_context * 
 ctx, GLenum name)
  
   switch (name) {
   case GL_VENDOR:
 - return (GLubyte *) Tungsten Graphics, Inc.;
 + return (GLubyte *) VMware, Inc.;
  
   case GL_RENDERER:
   {

___
mesa-dev mailing list
mesa-dev@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/mesa-dev


Re: [Mesa-dev] [PATCH 2/2] s/Tungsten Graphics/VMware/

2014-01-17 Thread Brian Paul

On 01/17/2014 12:56 PM, Ian Romanick wrote:

On 01/17/2014 08:33 AM, jfons...@vmware.com wrote:

diff --git a/src/mesa/drivers/dri/r200/r200_context.c 
b/src/mesa/drivers/dri/r200/r200_context.c
index f82424b..f613e56 100644
--- a/src/mesa/drivers/dri/r200/r200_context.c
+++ b/src/mesa/drivers/dri/r200/r200_context.c
@@ -29,7 +29,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.

  /*
   * Authors:
  *   Keith Whitwell ke...@tungstengraphics.com
   */

  #include stdbool.h
@@ -80,7 +80,7 @@ static const GLubyte *r200GetString( struct gl_context *ctx, 
GLenum name )

 switch ( name ) {
 case GL_VENDOR:
-  return (GLubyte *)Tungsten Graphics, Inc.;
+  return (GLubyte *)VMware, Inc.;



Since VMware isn't maintaining radeon or r200, I seems like this should
be Mesa Project, like swrast.


Yeah, the last thing we need is people contacting us when they have 
problems with these drivers.


-Brian


___
mesa-dev mailing list
mesa-dev@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/mesa-dev


Re: [Mesa-dev] [PATCH 2/2] s/Tungsten Graphics/VMware/

2014-01-17 Thread Jose Fonseca


- Original Message -
 On 01/17/2014 12:56 PM, Ian Romanick wrote:
  On 01/17/2014 08:33 AM, jfons...@vmware.com wrote:
  diff --git a/src/mesa/drivers/dri/r200/r200_context.c
@@ -29,7 +29,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
  /*
   * Authors:
- *   Keith Whitwell ke...@tungstengraphics.com
+ *   Keith Whitwell kei...@vmware.com
   */

  b/src/mesa/drivers/dri/r200/r200_context.c
  index f82424b..f613e56 100644
  --- a/src/mesa/drivers/dri/r200/r200_context.c
  +++ b/src/mesa/drivers/dri/r200/r200_context.c
  @@ -29,7 +29,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.
 
    /*
     * Authors:
  - *   Keith Whitwell ke...@tungstengraphics.com
  + *   Keith Whitwell kei...@vmware.com
     */
 
    #include stdbool.h
  @@ -80,7 +80,7 @@ static const GLubyte *r200GetString( struct gl_context
  *ctx, GLenum name )
 
       switch ( name ) {
       case GL_VENDOR:
  -      return (GLubyte *)Tungsten Graphics, Inc.;
  +      return (GLubyte *)VMware, Inc.;
 
 
  Since VMware isn't maintaining radeon or r200, I seems like this should
  be Mesa Project, like swrast.
 
 Yeah, the last thing we need is people contacting us when they have
 problems with these drivers.

Sounds good to me too.

Jose
___
mesa-dev mailing list
mesa-dev@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/mesa-dev